Module prepared

Module prepared 

Prepared PostgreSQL statements: SQL split around its parameter slots.

Structs

OwnedPreparedStatement
A PreparedStatement that owns all its values, so it has no lifetime.
PreparedStatement
A PostgreSQL statement rendered once, with its parameter slots, for reuse.