pub trait SQLViewInfo: SQLTableInfo + Any {
// Required method
fn definition_sql(&self) -> Cow<'static, str>;
// Provided methods
fn is_existing(&self) -> bool { ... }
fn is_materialized(&self) -> bool { ... }
fn with_no_data(&self) -> Option<bool> { ... }
fn using_clause(&self) -> Option<&'static str> { ... }
fn tablespace(&self) -> Option<&'static str> { ... }
}Expand description
Runtime metadata of a view, usable as a trait object.
Required Methods
Sourcefn definition_sql(&self) -> Cow<'static, str>
fn definition_sql(&self) -> Cow<'static, str>
Returns the view’s defining query as SQL text.
Provided Methods
Sourcefn is_existing(&self) -> bool
fn is_existing(&self) -> bool
Returns true for a view that already exists in the database and is
not created or dropped by Drizzle.
Sourcefn is_materialized(&self) -> bool
fn is_materialized(&self) -> bool
Returns true for a materialized view.
Sourcefn with_no_data(&self) -> Option<bool>
fn with_no_data(&self) -> Option<bool>
For a materialized view, whether it is created WITH NO DATA.
Sourcefn using_clause(&self) -> Option<&'static str>
fn using_clause(&self) -> Option<&'static str>
For a materialized view, its USING access method.
Sourcefn tablespace(&self) -> Option<&'static str>
fn tablespace(&self) -> Option<&'static str>
For a materialized view, its TABLESPACE.