Module helpers

Module helpers 

SQL fragment builders used by the PostgreSQL query builders.

Most items are internal. The public ones render join fragments for hand-built SQL: join, left_join, natural_join and the other *_join functions (JOIN table ON condition), and the PostgreSQL-only *_join_using functions (JOIN table USING (columns)). JoinArg is the argument type of the select builder’s .join(...) methods.

Structs

Join
The JOIN keyword of a join clause, such as NATURAL LEFT OUTER JOIN.

Traits

JoinArg
Trait for arguments accepted by .join() and related join methods.

Functions

cross_join
Compatibility helper for a conditional cross join.
full_join
Renders FULL JOIN table ON condition.
full_join_using
Renders FULL JOIN table USING (columns). See join_using for how to pass columns.
full_outer_join
Renders FULL OUTER JOIN table ON condition.
full_outer_join_using
Renders FULL OUTER JOIN table USING (columns). See join_using for how to pass columns.
inner_join
Renders INNER JOIN table ON condition.
inner_join_using
Renders INNER JOIN table USING (columns). See join_using for how to pass columns.
join
Renders JOIN table ON condition.
join_using
Renders JOIN table USING (columns), which joins rows whose same-named columns are equal.
left_join
Renders LEFT JOIN table ON condition.
left_join_using
Renders LEFT JOIN table USING (columns). See join_using for how to pass columns.
left_outer_join
Renders LEFT OUTER JOIN table ON condition.
left_outer_join_using
Renders LEFT OUTER JOIN table USING (columns). See join_using for how to pass columns.
natural_full_join
Renders NATURAL FULL JOIN table.
natural_full_outer_join
Renders NATURAL FULL OUTER JOIN table.
natural_inner_join
Renders NATURAL INNER JOIN table.
natural_join
Renders NATURAL JOIN table.
natural_left_join
Renders NATURAL LEFT JOIN table.
natural_left_outer_join
Renders NATURAL LEFT OUTER JOIN table.
natural_right_join
Renders NATURAL RIGHT JOIN table.
natural_right_outer_join
Renders NATURAL RIGHT OUTER JOIN table.
right_join
Renders RIGHT JOIN table ON condition.
right_join_using
Renders RIGHT JOIN table USING (columns). See join_using for how to pass columns.
right_outer_join
Renders RIGHT OUTER JOIN table ON condition.
right_outer_join_using
Renders RIGHT OUTER JOIN table USING (columns). See join_using for how to pass columns.