Join

Struct Join 

pub struct Join {
    pub natural: bool,
    pub join_type: JoinType,
    pub outer: bool,
}
The JOIN keyword of a join clause, such as NATURAL LEFT OUTER JOIN.

Built with const methods, so it can be a constant. Renders through ToSQL.

Examples

use drizzle_core::{Join, SQL, ToSQL};

let sql: SQL<'_, Value> = Join::new().left().outer().to_sql();
assert_eq!(sql.sql(), "LEFT OUTER JOIN");

Fields

natural: bool

Adds NATURAL.

join_type: JoinType

The kind of join.

outer: bool

Adds OUTER. Only used for LEFT, RIGHT and FULL.

Implementations

Source

impl Join

pub const fn new() -> Join

Creates a plain JOIN.

pub const fn natural(self) -> Join

Makes this a NATURAL join.

pub const fn inner(self) -> Join

Makes this an INNER join.

pub const fn left(self) -> Join

Makes this a LEFT join.

pub const fn right(self) -> Join

Makes this a RIGHT join.

pub const fn full(self) -> Join

Makes this a FULL join.

pub const fn cross(self) -> Join

Makes this a CROSS join.

pub const fn outer(self) -> Join

Adds OUTER (LEFT OUTER, RIGHT OUTER, FULL OUTER). Ignored for other kinds.