Traits for PostgreSQL tables, columns, enums and custom column types,
and for decoding values and driver rows.
The macros implement most of these: #[PostgresTable] implements
PostgresTable and PostgresColumn, and #[derive(PostgresEnum)]
implements DrizzlePostgresColumn (and PostgresEnum for native enums).
Implement FromPostgresValue yourself to decode a custom type.
Traits
- Drizzle
Postgres Column - A custom Rust type that can be used as a
PostgreSQLcolumn type (variant without a driver feature). - Drizzle
RowBy Index - A driver row whose columns can be read by position.
- Drizzle
RowBy Name - A driver row whose columns can be read by name.
- From
Postgres Value - A Rust type that can be built from a
PostgresValue. - Postgres
Column - A column of a
PostgreSQLtable, with its auto-increment settings. - Postgres
Enum - Object-safe view of a Rust enum stored as a
PostgreSQLenum value. - Postgres
Table - A
PostgreSQLtable. Implemented by#[PostgresTable].