pub trait DrizzleRowByName: DrizzleRowByIndex {
// Required method
fn get_column_by_name<T: FromPostgresValue>(
&self,
name: &str,
) -> Result<T, DrizzleError>;
}Expand description
A driver row whose columns can be read by name.
Required Methods
Sourcefn get_column_by_name<T: FromPostgresValue>(
&self,
name: &str,
) -> Result<T, DrizzleError>
fn get_column_by_name<T: FromPostgresValue>( &self, name: &str, ) -> Result<T, DrizzleError>
Reads the column named name as T.
Errors
Returns DrizzleError if the column name is unknown, the value is NULL for a non-nullable target,
or the stored value cannot be converted into T.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".