RefreshMaterializedView

Struct RefreshMaterializedView 

pub struct RefreshMaterializedView<'a, State = RefreshInitial> { /* private fields */ }
Builder for REFRESH MATERIALIZED VIEW statements

PostgreSQL syntax:

REFRESH MATERIALIZED VIEW [ CONCURRENTLY ] view_name [ WITH [ NO ] DATA ]

Note: CONCURRENTLY and WITH NO DATA are mutually exclusive in PostgreSQL. CONCURRENTLY requires the materialized view to have a unique index.

Implementations

Source

impl<'a> RefreshMaterializedView<'a, RefreshInitial>

pub fn new<V: SQLViewInfo>(view: &'a V) -> Self

Creates a new REFRESH MATERIALIZED VIEW builder for the given view

pub fn concurrently(self) -> RefreshMaterializedView<'a, RefreshConcurrently>

Adds the CONCURRENTLY option

This allows the view to be refreshed without locking out concurrent reads. Requires the materialized view to have at least one unique index.

Note: Cannot be combined with WITH NO DATA.

pub fn with_no_data(self) -> RefreshMaterializedView<'a, RefreshWithNoData>

Adds the WITH NO DATA option

This causes the materialized view to be emptied rather than refreshed with data. The view cannot be queried until data is added with a subsequent REFRESH.

Note: Cannot be combined with CONCURRENTLY.

pub fn with_data(self) -> Self

Adds the WITH DATA option (explicit, but this is the default behavior)