pub trait IntoSelect<'a, S, M, R> {
type State: ExecutableState;
type Table;
// Required method
fn into_select(self) -> SelectBuilder<'a, S, Self::State, Self::Table, M, R>;
}Expand description
Conversion trait for types that can become a SelectBuilder.
Used by set operations to accept both raw SelectBuilder and DrizzleBuilder.
Required Associated Types
type State: ExecutableState
type Table
Required Methods
fn into_select(self) -> SelectBuilder<'a, S, Self::State, Self::Table, M, R>
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".