QueryBuilder

Struct QueryBuilder 

pub struct QueryBuilder<'a, Schema = (), State = (), Table = ()> {
    pub sql: SQL<'a, PostgresValue<'a>>,
    /* private fields */
}
Main query builder for PostgreSQL

The S type parameter represents the schema type, which is used to ensure type safety when building queries.

Fields

sql: SQL<'a, PostgresValue<'a>>

Implementations

Source

impl<'a, S, T> QueryBuilder<'a, S, DeleteInitial, T>

pub fn where( self, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> DeleteBuilder<'a, S, DeleteWhereSet, T>

Adds a WHERE condition to the query

pub fn returning( self, columns: impl ToSQL<'a, PostgresValue<'a>>, ) -> DeleteBuilder<'a, S, DeleteReturningSet, T>

Adds a RETURNING clause to the query

Source

impl<'a, S, T> QueryBuilder<'a, S, DeleteWhereSet, T>

pub fn returning( self, columns: impl ToSQL<'a, PostgresValue<'a>>, ) -> DeleteBuilder<'a, S, DeleteReturningSet, T>

Adds a RETURNING clause after WHERE

Source

impl<'a, Schema, Table> QueryBuilder<'a, Schema, InsertInitial, Table>
where Table: PostgresTable<'a>,

pub fn values<I, T>( self, values: I, ) -> InsertBuilder<'a, Schema, InsertValuesSet, Table>
where I: IntoIterator<Item = Table::Insert<T>>,

Sets values to insert and transitions to ValuesSet state

Source

impl<'a, S, T> QueryBuilder<'a, S, InsertValuesSet, T>

pub fn on_conflict( self, conflict: Conflict<'a>, ) -> InsertBuilder<'a, S, InsertOnConflictSet, T>

Adds conflict resolution clause following PostgreSQL ON CONFLICT syntax

pub fn on_conflict_do_nothing( self, ) -> InsertBuilder<'a, S, InsertOnConflictSet, T>

Shorthand for ON CONFLICT DO NOTHING (matches any conflict)

pub fn on_conflict_do_nothing_on<C>( self, columns: C, ) -> InsertBuilder<'a, S, InsertOnConflictSet, T>
where C: ToSQL<'a, PostgresValue<'a>>,

Shorthand for ON CONFLICT (columns…) DO NOTHING

pub fn returning( self, columns: impl ToSQL<'a, PostgresValue<'a>>, ) -> InsertBuilder<'a, S, InsertReturningSet, T>

Adds a RETURNING clause and transitions to ReturningSet state

Source

impl<'a, S, T> QueryBuilder<'a, S, InsertOnConflictSet, T>

pub fn returning( self, columns: impl ToSQL<'a, PostgresValue<'a>>, ) -> InsertBuilder<'a, S, InsertReturningSet, T>

Adds a RETURNING clause after ON CONFLICT

Source

impl<'a, S> QueryBuilder<'a, S, SelectInitial>

pub fn from<T>(self, query: T) -> SelectBuilder<'a, S, SelectFromSet, T>
where T: ToSQL<'a, PostgresValue<'a>>,

Specifies the table to select FROM and transitions state

Source

impl<'a, S, T> QueryBuilder<'a, S, SelectFromSet, T>

pub fn join<U: PostgresTable<'a>>( self, table: U, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

Adds a JOIN clause to the query

pub fn natural_join<U: PostgresTable<'a>>( self, table: U, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with ON clause

pub fn natural_left_join<U: PostgresTable<'a>>( self, table: U, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with ON clause

pub fn left_join<U: PostgresTable<'a>>( self, table: U, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with ON clause

pub fn left_outer_join<U: PostgresTable<'a>>( self, table: U, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with ON clause

pub fn natural_left_outer_join<U: PostgresTable<'a>>( self, table: U, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with ON clause

pub fn natural_right_join<U: PostgresTable<'a>>( self, table: U, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with ON clause

pub fn right_join<U: PostgresTable<'a>>( self, table: U, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with ON clause

pub fn right_outer_join<U: PostgresTable<'a>>( self, table: U, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with ON clause

pub fn natural_right_outer_join<U: PostgresTable<'a>>( self, table: U, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with ON clause

pub fn natural_full_join<U: PostgresTable<'a>>( self, table: U, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with ON clause

pub fn full_join<U: PostgresTable<'a>>( self, table: U, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with ON clause

pub fn full_outer_join<U: PostgresTable<'a>>( self, table: U, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with ON clause

pub fn natural_full_outer_join<U: PostgresTable<'a>>( self, table: U, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with ON clause

pub fn inner_join<U: PostgresTable<'a>>( self, table: U, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with ON clause

pub fn cross_join<U: PostgresTable<'a>>( self, table: U, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with ON clause

pub fn left_join_using<U: PostgresTable<'a>>( self, table: U, columns: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with USING clause (PostgreSQL-specific)

pub fn left_outer_join_using<U: PostgresTable<'a>>( self, table: U, columns: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with USING clause (PostgreSQL-specific)

pub fn right_join_using<U: PostgresTable<'a>>( self, table: U, columns: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with USING clause (PostgreSQL-specific)

pub fn right_outer_join_using<U: PostgresTable<'a>>( self, table: U, columns: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with USING clause (PostgreSQL-specific)

pub fn full_join_using<U: PostgresTable<'a>>( self, table: U, columns: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with USING clause (PostgreSQL-specific)

pub fn full_outer_join_using<U: PostgresTable<'a>>( self, table: U, columns: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with USING clause (PostgreSQL-specific)

pub fn inner_join_using<U: PostgresTable<'a>>( self, table: U, columns: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with USING clause (PostgreSQL-specific)

pub fn join_using<U: PostgresTable<'a>>( self, table: U, columns: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with USING clause (PostgreSQL-specific)

pub fn where( self, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectWhereSet, T>

pub fn group_by( self, expressions: impl IntoIterator<Item = impl ToSQL<'a, PostgresValue<'a>>>, ) -> SelectBuilder<'a, S, SelectGroupSet, T>

Adds a GROUP BY clause to the query

pub fn limit(self, limit: usize) -> SelectBuilder<'a, S, SelectLimitSet, T>

Limits the number of rows returned

pub fn offset(self, offset: usize) -> SelectBuilder<'a, S, SelectOffsetSet, T>

Sets the offset for the query results

pub fn order_by<TOrderBy>( self, expressions: TOrderBy, ) -> SelectBuilder<'a, S, SelectOrderSet, T>
where TOrderBy: ToSQL<'a, PostgresValue<'a>>,

Sorts the query results

Source

impl<'a, S, T> QueryBuilder<'a, S, SelectJoinSet, T>

pub fn where( self, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectWhereSet, T>

Adds a WHERE condition after a JOIN

pub fn order_by<TOrderBy>( self, expressions: TOrderBy, ) -> SelectBuilder<'a, S, SelectOrderSet, T>
where TOrderBy: ToSQL<'a, PostgresValue<'a>>,

Sorts the query results

pub fn join<U: PostgresTable<'a>>( self, table: U, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

Adds a JOIN clause to the query

pub fn natural_join<U: PostgresTable<'a>>( self, table: U, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with ON clause

pub fn natural_left_join<U: PostgresTable<'a>>( self, table: U, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with ON clause

pub fn left_join<U: PostgresTable<'a>>( self, table: U, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with ON clause

pub fn left_outer_join<U: PostgresTable<'a>>( self, table: U, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with ON clause

pub fn natural_left_outer_join<U: PostgresTable<'a>>( self, table: U, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with ON clause

pub fn natural_right_join<U: PostgresTable<'a>>( self, table: U, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with ON clause

pub fn right_join<U: PostgresTable<'a>>( self, table: U, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with ON clause

pub fn right_outer_join<U: PostgresTable<'a>>( self, table: U, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with ON clause

pub fn natural_right_outer_join<U: PostgresTable<'a>>( self, table: U, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with ON clause

pub fn natural_full_join<U: PostgresTable<'a>>( self, table: U, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with ON clause

pub fn full_join<U: PostgresTable<'a>>( self, table: U, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with ON clause

pub fn full_outer_join<U: PostgresTable<'a>>( self, table: U, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with ON clause

pub fn natural_full_outer_join<U: PostgresTable<'a>>( self, table: U, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with ON clause

pub fn inner_join<U: PostgresTable<'a>>( self, table: U, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with ON clause

pub fn cross_join<U: PostgresTable<'a>>( self, table: U, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with ON clause

pub fn left_join_using<U: PostgresTable<'a>>( self, table: U, columns: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with USING clause (PostgreSQL-specific)

pub fn left_outer_join_using<U: PostgresTable<'a>>( self, table: U, columns: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with USING clause (PostgreSQL-specific)

pub fn right_join_using<U: PostgresTable<'a>>( self, table: U, columns: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with USING clause (PostgreSQL-specific)

pub fn right_outer_join_using<U: PostgresTable<'a>>( self, table: U, columns: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with USING clause (PostgreSQL-specific)

pub fn full_join_using<U: PostgresTable<'a>>( self, table: U, columns: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with USING clause (PostgreSQL-specific)

pub fn full_outer_join_using<U: PostgresTable<'a>>( self, table: U, columns: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with USING clause (PostgreSQL-specific)

pub fn inner_join_using<U: PostgresTable<'a>>( self, table: U, columns: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with USING clause (PostgreSQL-specific)

pub fn join_using<U: PostgresTable<'a>>( self, table: U, columns: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectJoinSet, T>

JOIN with USING clause (PostgreSQL-specific)

Source

impl<'a, S, T> QueryBuilder<'a, S, SelectWhereSet, T>

pub fn group_by( self, expressions: impl IntoIterator<Item = impl ToSQL<'a, PostgresValue<'a>>>, ) -> SelectBuilder<'a, S, SelectGroupSet, T>

Adds a GROUP BY clause after a WHERE

pub fn order_by<TOrderBy>( self, expressions: TOrderBy, ) -> SelectBuilder<'a, S, SelectOrderSet, T>
where TOrderBy: ToSQL<'a, PostgresValue<'a>>,

Adds an ORDER BY clause after a WHERE

pub fn limit(self, limit: usize) -> SelectBuilder<'a, S, SelectLimitSet, T>

Adds a LIMIT clause after a WHERE

Source

impl<'a, S, T> QueryBuilder<'a, S, SelectGroupSet, T>

pub fn having( self, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectGroupSet, T>

Adds a HAVING clause after GROUP BY

pub fn order_by<TOrderBy>( self, expressions: TOrderBy, ) -> SelectBuilder<'a, S, SelectOrderSet, T>
where TOrderBy: ToSQL<'a, PostgresValue<'a>>,

Adds an ORDER BY clause after GROUP BY

Source

impl<'a, S, T> QueryBuilder<'a, S, SelectOrderSet, T>

pub fn limit(self, limit: usize) -> SelectBuilder<'a, S, SelectLimitSet, T>

Adds a LIMIT clause after ORDER BY

Source

impl<'a, S, T> QueryBuilder<'a, S, SelectLimitSet, T>

pub fn offset(self, offset: usize) -> SelectBuilder<'a, S, SelectOffsetSet, T>

Adds an OFFSET clause after LIMIT

Source

impl<'a, S, State, T> QueryBuilder<'a, S, State, T>
where State: AsCteState, T: SQLTable<'a, PostgresSchemaType, PostgresValue<'a>>,

pub fn into_cte( self, name: &'static str, ) -> CTEView<'a, <T as SQLTable<'a, PostgresSchemaType, PostgresValue<'a>>>::Aliased, Self>

Converts this SELECT query into a CTE (Common Table Expression) with the given name.

Source

impl<'a, S, State, T> QueryBuilder<'a, S, State, T>
where State: ExecutableState,

pub fn union( self, other: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectSetOpSet, T>

Combines this query with another using UNION.

pub fn union_all( self, other: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectSetOpSet, T>

Combines this query with another using UNION ALL.

pub fn intersect( self, other: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectSetOpSet, T>

Combines this query with another using INTERSECT.

pub fn intersect_all( self, other: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectSetOpSet, T>

Combines this query with another using INTERSECT ALL.

pub fn except( self, other: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectSetOpSet, T>

Combines this query with another using EXCEPT.

pub fn except_all( self, other: impl ToSQL<'a, PostgresValue<'a>>, ) -> SelectBuilder<'a, S, SelectSetOpSet, T>

Combines this query with another using EXCEPT ALL.

Source

impl<'a, S, T> QueryBuilder<'a, S, SelectSetOpSet, T>

pub fn order_by<TOrderBy>( self, expressions: TOrderBy, ) -> SelectBuilder<'a, S, SelectOrderSet, T>
where TOrderBy: ToSQL<'a, PostgresValue<'a>>,

Sorts the results of a set operation.

pub fn limit(self, limit: usize) -> SelectBuilder<'a, S, SelectLimitSet, T>

Limits the results of a set operation.

pub fn offset(self, offset: usize) -> SelectBuilder<'a, S, SelectOffsetSet, T>

Offsets the results of a set operation.

Source

impl<'a, S, State, T> QueryBuilder<'a, S, State, T>
where State: ForLockableState,

pub fn for_update(self) -> SelectBuilder<'a, S, SelectForSet, T>

Adds FOR UPDATE clause to lock selected rows for update.

This prevents other transactions from modifying or locking the selected rows until the current transaction ends.

Example
db.select(()).from(users).where(eq(users.id, 1)).for_update()
// SELECT ... FROM "users" WHERE "id" = $1 FOR UPDATE
pub fn for_share(self) -> SelectBuilder<'a, S, SelectForSet, T>

Adds FOR SHARE clause to lock selected rows for shared access.

This allows other transactions to read the rows but prevents them from modifying or exclusively locking them.

Example
db.select(()).from(users).where(eq(users.id, 1)).for_share()
// SELECT ... FROM "users" WHERE "id" = $1 FOR SHARE
pub fn for_no_key_update(self) -> SelectBuilder<'a, S, SelectForSet, T>

Adds FOR NO KEY UPDATE clause.

Similar to FOR UPDATE but weaker - allows SELECT FOR KEY SHARE on the same rows.

Example
db.select(()).from(users).where(eq(users.id, 1)).for_no_key_update()
// SELECT ... FROM "users" WHERE "id" = $1 FOR NO KEY UPDATE
pub fn for_key_share(self) -> SelectBuilder<'a, S, SelectForSet, T>

Adds FOR KEY SHARE clause.

The weakest lock - only blocks SELECT FOR UPDATE.

Example
db.select(()).from(users).where(eq(users.id, 1)).for_key_share()
// SELECT ... FROM "users" WHERE "id" = $1 FOR KEY SHARE
pub fn for_update_of<U: PostgresTable<'a>>( self, table: U, ) -> SelectBuilder<'a, S, SelectForSet, T>

Adds FOR UPDATE OF table clause to lock only rows from a specific table.

Useful in joins to specify which table’s rows should be locked. Note: Uses unqualified table name per PostgreSQL requirements.

Example
db.select(())
    .from(users)
    .join(orders, eq(users.id, orders.user_id))
    .for_update_of(users)
// SELECT ... FOR UPDATE OF "users"
pub fn for_share_of<U: PostgresTable<'a>>( self, table: U, ) -> SelectBuilder<'a, S, SelectForSet, T>

Adds FOR SHARE OF table clause to lock only rows from a specific table.

Useful in joins to specify which table’s rows should be locked. Note: Uses unqualified table name per PostgreSQL requirements.

Example
db.select(())
    .from(users)
    .join(orders, eq(users.id, orders.user_id))
    .for_share_of(users)
// SELECT ... FOR SHARE OF "users"
Source

impl<'a, S, T> QueryBuilder<'a, S, SelectForSet, T>

pub fn nowait(self) -> SelectBuilder<'a, S, SelectForSet, T>

Adds NOWAIT option to fail immediately if rows are locked.

Instead of waiting for locked rows to become available, the query will fail with an error if any selected rows are currently locked.

Example
db.select(()).from(users).for_update().nowait()
// SELECT ... FOR UPDATE NOWAIT
pub fn skip_locked(self) -> SelectBuilder<'a, S, SelectForSet, T>

Adds SKIP LOCKED option to skip over locked rows.

Instead of waiting for locked rows, the query will skip them and only return/lock rows that are currently available.

Example
db.select(()).from(jobs).where(eq(jobs.status, "pending")).for_update().skip_locked()
// SELECT ... FOR UPDATE SKIP LOCKED
Source

impl<'a, Schema, Table> QueryBuilder<'a, Schema, UpdateInitial, Table>
where Table: SQLTable<'a, PostgresSchemaType, PostgresValue<'a>>,

pub fn set( self, values: Table::Update, ) -> UpdateBuilder<'a, Schema, UpdateSetClauseSet, Table>

Sets the values to update and transitions to the SetClauseSet state

Source

impl<'a, S, T> QueryBuilder<'a, S, UpdateSetClauseSet, T>

pub fn from( self, source: impl ToSQL<'a, PostgresValue<'a>>, ) -> UpdateBuilder<'a, S, UpdateFromSet, T>

Adds a FROM clause and transitions to the FromSet state

pub fn where( self, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> UpdateBuilder<'a, S, UpdateWhereSet, T>

Adds a WHERE condition and transitions to the WhereSet state

pub fn returning( self, columns: impl ToSQL<'a, PostgresValue<'a>>, ) -> UpdateBuilder<'a, S, UpdateReturningSet, T>

Adds a RETURNING clause and transitions to the ReturningSet state

Source

impl<'a, S, T> QueryBuilder<'a, S, UpdateFromSet, T>

pub fn where( self, condition: impl ToSQL<'a, PostgresValue<'a>>, ) -> UpdateBuilder<'a, S, UpdateWhereSet, T>

Adds a WHERE condition after FROM

pub fn returning( self, columns: impl ToSQL<'a, PostgresValue<'a>>, ) -> UpdateBuilder<'a, S, UpdateReturningSet, T>

Adds a RETURNING clause after FROM

Source

impl<'a, S, T> QueryBuilder<'a, S, UpdateWhereSet, T>

pub fn returning( self, columns: impl ToSQL<'a, PostgresValue<'a>>, ) -> UpdateBuilder<'a, S, UpdateReturningSet, T>

Adds a RETURNING clause after WHERE

Source

impl<'a> QueryBuilder<'a>

pub const fn new<S>() -> QueryBuilder<'a, S, BuilderInit>

Creates a new query builder for the given schema

Source

impl<'a, Schema> QueryBuilder<'a, Schema, BuilderInit>

pub fn select<T>(&self, columns: T) -> SelectBuilder<'a, Schema, SelectInitial>
where T: ToSQL<'a, PostgresValue<'a>>,

pub fn select_distinct<T>( &self, columns: T, ) -> SelectBuilder<'a, Schema, SelectInitial>
where T: ToSQL<'a, PostgresValue<'a>>,

Begins a SELECT DISTINCT query with the specified columns.

SELECT DISTINCT removes duplicate rows from the result set.

pub fn select_distinct_on<On, Columns>( &self, on: On, columns: Columns, ) -> SelectBuilder<'a, Schema, SelectInitial>
where On: ToSQL<'a, PostgresValue<'a>>, Columns: ToSQL<'a, PostgresValue<'a>>,

Begins a SELECT DISTINCT ON query with the specified columns.

Source

impl<'a, Schema> QueryBuilder<'a, Schema, CTEInit>

pub fn select<T>(&self, columns: T) -> SelectBuilder<'a, Schema, SelectInitial>
where T: ToSQL<'a, PostgresValue<'a>>,

pub fn select_distinct<T>( &self, columns: T, ) -> SelectBuilder<'a, Schema, SelectInitial>
where T: ToSQL<'a, PostgresValue<'a>>,

Begins a SELECT DISTINCT query with the specified columns after a CTE.

pub fn select_distinct_on<On, Columns>( &self, on: On, columns: Columns, ) -> SelectBuilder<'a, Schema, SelectInitial>
where On: ToSQL<'a, PostgresValue<'a>>, Columns: ToSQL<'a, PostgresValue<'a>>,

Begins a SELECT DISTINCT ON query with the specified columns after a CTE.

pub fn insert<Table>( &self, table: Table, ) -> InsertBuilder<'a, Schema, InsertInitial, Table>
where Table: PostgresTable<'a>,

Begins an INSERT query after a CTE.

pub fn update<Table>( &self, table: Table, ) -> UpdateBuilder<'a, Schema, UpdateInitial, Table>
where Table: PostgresTable<'a>,

Begins an UPDATE query after a CTE.

pub fn delete<Table>( &self, table: Table, ) -> DeleteBuilder<'a, Schema, DeleteInitial, Table>
where Table: PostgresTable<'a>,

Begins a DELETE query after a CTE.

pub fn with<C>(&self, cte: C) -> QueryBuilder<'a, Schema, CTEInit>
where C: CTEDefinition<'a>,

Source

impl<'a, Schema> QueryBuilder<'a, Schema, BuilderInit>

pub fn insert<Table>( &self, table: Table, ) -> InsertBuilder<'a, Schema, InsertInitial, Table>
where Table: PostgresTable<'a>,

pub fn update<Table>( &self, table: Table, ) -> UpdateBuilder<'a, Schema, UpdateInitial, Table>
where Table: PostgresTable<'a>,

pub fn delete<Table>( &self, table: Table, ) -> DeleteBuilder<'a, Schema, DeleteInitial, Table>
where Table: PostgresTable<'a>,

pub fn with<C>(&self, cte: C) -> QueryBuilder<'a, Schema, CTEInit>
where C: CTEDefinition<'a>,