pub trait ExecutableState { }Expand description
Marker trait for executable builder states.
This is an extension point for driver crates to opt in builder state markers that represent complete, executable queries (for example, to enable set operations or prepared statements on those states).