SQLViewInfo

Trait SQLViewInfo 

pub trait SQLViewInfo: SQLTableInfo + Any {
    // Required method
    fn definition_sql(&self) -> Cow<'static, str>;

    // Provided methods
    fn is_existing(&self) -> bool { ... }
    fn is_materialized(&self) -> bool { ... }
    fn with_no_data(&self) -> Option<bool> { ... }
    fn using_clause(&self) -> Option<&'static str> { ... }
    fn tablespace(&self) -> Option<&'static str> { ... }
}
Runtime metadata of a view, usable as a trait object.

Required Methods

fn definition_sql(&self) -> Cow<'static, str>

Returns the view’s defining query as SQL text.

Provided Methods

fn is_existing(&self) -> bool

Returns true for a view that already exists in the database and is not created or dropped by Drizzle.

fn is_materialized(&self) -> bool

Returns true for a materialized view.

fn with_no_data(&self) -> Option<bool>

For a materialized view, whether it is created WITH NO DATA.

fn using_clause(&self) -> Option<&'static str>

For a materialized view, its USING access method.

fn tablespace(&self) -> Option<&'static str>

For a materialized view, its TABLESPACE.