Module traits

Module traits 

Traits

DrizzlePostgresColumn
Stub trait when no postgres driver is enabled — allows enum derives to compile without a driver feature, but the table macro’s TryFrom impls won’t be generated.
DrizzleRowByIndex
Row capability for index-based extraction.
DrizzleRowByName
Row capability for name-based extraction.
FromPostgresValue
Trait for types that can be converted from PostgreSQL values.
PostgresColumn
PostgresEnum
Trait for PostgreSQL native enum types that can be used as dyn objects
PostgresTable