Traits
- Drizzle
Postgres Column - Stub trait when no postgres driver is enabled — allows enum derives to compile
without a driver feature, but the table macro’s
TryFromimpls won’t be generated. - Drizzle
RowBy Index - Row capability for index-based extraction.
- Drizzle
RowBy Name - Row capability for name-based extraction.
- From
Postgres Value - Trait for types that can be converted from
PostgreSQLvalues. - Postgres
Column - Postgres
Enum - Trait for
PostgreSQLnative enum types that can be used as dyn objects - Postgres
Table