Module traits

Module traits 

Traits

DrizzleRowByIndex
Row capability for index-based extraction.
DrizzleRowByName
Row capability for name-based extraction.
FromPostgresValue
Trait for types that can be converted from PostgreSQL values.
PostgresColumn
PostgresColumnInfo
PostgresEnum
Trait for PostgreSQL native enum types that can be used as dyn objects
PostgresTable
PostgresTableInfo