pub trait DrizzleRowByIndex {
// Required method
fn get_column<T: FromPostgresValue>(
&self,
idx: usize,
) -> Result<T, DrizzleError>;
}Expand description
Row capability for index-based extraction.
Required Methods
Sourcefn get_column<T: FromPostgresValue>(
&self,
idx: usize,
) -> Result<T, DrizzleError>
fn get_column<T: FromPostgresValue>( &self, idx: usize, ) -> Result<T, DrizzleError>
Get a column value by index
Errors
Returns DrizzleError if the column is out of bounds, the value is NULL for a non-nullable target,
or the stored value cannot be converted into T.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".