pub trait DrizzleRowByIndex {
// Required method
fn get_column<T: FromPostgresValue>(
&self,
idx: usize,
) -> Result<T, DrizzleError>;
}Expand description
A driver row whose columns can be read by position.
Required Methods
Sourcefn get_column<T: FromPostgresValue>(
&self,
idx: usize,
) -> Result<T, DrizzleError>
fn get_column<T: FromPostgresValue>( &self, idx: usize, ) -> Result<T, DrizzleError>
Reads column idx (zero-based) as T.
Errors
Returns DrizzleError if the column is out of bounds, the value is NULL for a non-nullable target,
or the stored value cannot be converted into T.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".