DrizzleRowByName

Trait DrizzleRowByName 

pub trait DrizzleRowByName: DrizzleRowByIndex {
    // Required method
    fn get_column_by_name<T: FromPostgresValue>(
        &self,
        name: &str,
    ) -> Result<T, DrizzleError>;
}
Row capability for name-based extraction.

Required Methods

fn get_column_by_name<T: FromPostgresValue>( &self, name: &str, ) -> Result<T, DrizzleError>

Get a column value by name

Errors

Returns DrizzleError if the column name is unknown, the value is NULL for a non-nullable target, or the stored value cannot be converted into T.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors