PostgresEnum

Trait PostgresEnum 

pub trait PostgresEnum:
    Send
    + Sync
    + Any {
    // Required methods
    fn enum_type_name(&self) -> &'static str;
    fn as_enum(&self) -> &dyn PostgresEnum;
    fn variant_name(&self) -> &'static str;
    fn into_boxed(&self) -> Box<dyn PostgresEnum>;
    fn try_from_str(value: &str) -> Result<Self, DrizzleError>
       where Self: Sized;
}
Trait for PostgreSQL native enum types that can be used as dyn objects

Required Methods

fn enum_type_name(&self) -> &'static str

Get the enum type name for PostgreSQL

fn as_enum(&self) -> &dyn PostgresEnum

fn variant_name(&self) -> &'static str

Get the string representation of this enum variant

fn into_boxed(&self) -> Box<dyn PostgresEnum>

Clone this enum as a boxed trait object

fn try_from_str(value: &str) -> Result<Self, DrizzleError>
where Self: Sized,

Try to create this enum from a string value

Errors

Returns DrizzleError::ConversionError when value is not a valid variant name for this enum.