PostgreSQL value conversion traits and types
Enums
- Owned
Postgres Value - Owned version of
PostgresValuethat doesn’t borrow data - Postgres
Insert Value - Represents a value for INSERT operations that can be omitted, null, or a SQL expression
- Postgres
Update Value - Represents a value for UPDATE operations that can be skipped, null, or a SQL expression.
- Postgres
Value - Represents a
PostgreSQLvalue.