Module values

Module values 

PostgreSQL value conversion traits and types

Enums

OwnedPostgresValue
Owned version of PostgresValue that doesn’t borrow data
PostgresInsertValue
Represents a value for INSERT operations that can be omitted, null, or a SQL expression
PostgresUpdateValue
Represents a value for UPDATE operations that can be skipped, null, or a SQL expression.
PostgresValue
Represents a PostgreSQL value.