pub enum OwnedPostgresValue {
Smallint(i16),
Integer(i32),
Bigint(i64),
Real(f32),
DoublePrecision(f64),
Text(String),
Bytea(Vec<u8>),
Boolean(bool),
Array(Vec<Self>),
Enum(Box<dyn PostgresEnum>),
Null,
}Expand description
Owned version of PostgresValue that doesn’t borrow data
Variants
Smallint(i16)
SMALLINT values (16-bit signed integer)
Integer(i32)
INTEGER values (32-bit signed integer)
Bigint(i64)
BIGINT values (64-bit signed integer)
Real(f32)
REAL values (32-bit floating point)
DoublePrecision(f64)
DOUBLE PRECISION values (64-bit floating point)
Text(String)
TEXT, VARCHAR, CHAR values (owned)
Bytea(Vec<u8>)
BYTEA values (owned binary data)
Boolean(bool)
BOOLEAN values
Array(Vec<Self>)
Array of any PostgreSQL type
Enum(Box<dyn PostgresEnum>)
PostgreSQL ENUM values (native enum types via CREATE TYPE ... AS ENUM)
Null
NULL value
Implementations
Sourceimpl OwnedPostgresValue
impl OwnedPostgresValue
Sourcepub fn as_value(&self) -> PostgresValue<'_>
pub fn as_value(&self) -> PostgresValue<'_>
Returns a borrowed PostgresValue view of this owned value.
Sourcepub fn convert<T: FromPostgresValue>(self) -> Result<T, DrizzleError>
pub fn convert<T: FromPostgresValue>(self) -> Result<T, DrizzleError>
Convert this PostgreSQL value to a Rust type using the FromPostgresValue trait.
Errors
Returns DrizzleError::ConversionError when the stored variant’s
native type does not match the target type T.
Sourcepub fn convert_ref<T: FromPostgresValue>(&self) -> Result<T, DrizzleError>
pub fn convert_ref<T: FromPostgresValue>(&self) -> Result<T, DrizzleError>
Convert a reference to this PostgreSQL value to a Rust type.
Errors
Returns DrizzleError::ConversionError when the stored variant’s
native type does not match the target type T.